parscival package
=================

Submodules
----------

parscival.worker module
-----------------------

.. automodule:: parscival.worker
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: parscival
   :members:
   :undoc-members:
   :show-inheritance:
